@@ -1,13 +1,13 @@
 package Plack::Middleware::XSRFBlock;
-$Plack::Middleware::XSRFBlock::VERSION = '0.0.9';
 {
   $Plack::Middleware::XSRFBlock::DIST = 'Plack-Middleware-XSRFBlock';
 }
-
+$Plack::Middleware::XSRFBlock::VERSION = '0.0.10';
 use strict;
 use warnings;
 use parent 'Plack::Middleware';
 
+
 use Digest::HMAC_SHA1 'hmac_sha1_hex';
 use HTML::Escape qw(escape_html);
 use HTML::Parser;
@@ -322,6 +322,7 @@ sub _set_cookie {
 1;
 
 
+
 # ABSTRACT: Block XSRF Attacks with minimal changes to your app
 
 =pod
@@ -334,7 +335,7 @@ Plack::Middleware::XSRFBlock - Block XSRF Attacks with minimal changes to your a
 
 =head1 VERSION
 
-version 0.0.9
+version 0.0.10
 
 =head1 SYNOPSIS
 
@@ -483,6 +484,12 @@ to the browser.
 
 =back
 
+=head2 invalid_signature($self, $value)
+
+=head2 xsrf_detected($self, $args)
+
+=head2 log($self, $level, $msg)
+
 =head1 EXPLANATION
 
 This module is similar in nature and intention to
@@ -552,6 +559,14 @@ L<Plack::Middleware::CSRFBlock>,
 L<Plack::Middleware>,
 L<Plack>
 
+=begin markdown
+
+## BUILD STATUS
+
+[![Build status](https://badge.buildkite.com/330e67514dd501f1827bcf33db423ccadf201caf5b2b563fbf.svg)](https://buildkite.com/chizography/plack-middleware-xsrfblock)
+
+=end markdown
+
 =head1 AUTHOR
 
 Chisel <chisel@chizography.net>
@@ -565,6 +580,8 @@ the same terms as the Perl 5 programming language system itself.
 
 =head1 CONTRIBUTORS
 
+=for stopwords Chisel Wright Matthew Ryall Matthias Zeichmann Michael Kröll Sebastian Willert William Wolf
+
 =over 4
 
 =item *
